@@ -2,7 +2,7 @@ pub use anyhow::{anyhow, Context as _};
 pub use tracing::{event, trace, debug, info, warn, error, Level};
 pub use tracing_tools::{span, TracingTask, PinnedFut as PinnedTask};
 
-pub use async_channel::{Sender, Receiver, RecvError, bounded as bounded_ch, unbounded as unbounded_ch};
+pub use flume::{Sender, Receiver, RecvError, bounded as bounded_ch, unbounded as unbounded_ch};
 pub use tokio::time::{self, Instant, Duration};
 pub use url::Url;
 
